@@ -17,22 +17,22 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
-__all__ = ["__author__", "__description__", "__license__", "__url__",
-           "__version__"]
+__all__ = ["__author__", "__description__", "__license__", "__url__", "__version__"]
 
 
-def git_hash():
+def git_describe():
     import subprocess
+
     try:
-        out = subprocess.check_output(["git", "rev-parse", "--short", "HEAD"],
-                                      stderr=subprocess.STDOUT)
+        # git describe?
+        out = subprocess.check_output(["git", "describe"], stderr=subprocess.STDOUT)
         return out.decode("utf-8").rstrip("\n")
     except Exception:
         return "git"
 
 
 __author__ = "Rémi Duraffort"
-__description__ = 'LAVA XML-RPC command line interface'
-__license__ = 'AGPLv3+'
-__url__ = 'https://git.linaro.org/lava/lavacli.git'
-__version__ = "0.9.2"
+__description__ = "LAVA XML-RPC command line interface"
+__license__ = "AGPLv3+"
+__url__ = "https://git.lavasoftware.org/lava/lavacli.git"
+__version__ = "0.9.3"
